<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Komgrit Niyomrath <n.komgrit@gmail.com>
 * @author Kittithat Arnontavilas <mrtomyum@gmail.com>
 * @author Arthit Suriyawongkul <arthit@gmail.com>
 * @author Thanasak Sompaisansin <jombthep@gmail.com>
 */
$lang['menu']                  = 'ตั้งค่าการปรับแต่ง';
$lang['updated']               = 'การปรับแต่งค่าถูกบันทึกเรียบร้อย';
$lang['_configuration_manager'] = 'จัดการการปรับตั้งค่า';
$lang['_header_dokuwiki']      = 'การตั้งค่า DokuWiki';
$lang['_header_plugin']        = 'การตั้งค่า Plugin';
$lang['_header_template']      = 'การตั้งค่าเทมเพลต';
$lang['_basic']                = 'การตั้งค่าพื้นฐาน';
$lang['_display']              = 'การตั้งค่าการแสดงผล';
$lang['_authentication']       = 'การตั้งค่าสิทธิ์การเข้าถึง';
$lang['_anti_spam']            = 'การตั้งค่าป้องกันสแปม';
$lang['_editing']              = 'การตั้งค่าการแก้ไขปรับปรุง';
$lang['_links']                = 'การตั้งค่าลิงก์';
$lang['_media']                = 'การตั้งค่าภาพ-เสียง';
$lang['_advanced']             = 'การตั้งค่าขั้นสูง';
$lang['_network']              = 'การตั้งค่าเครือข่าย';
$lang['start']                 = 'ชื่อหน้าเริ่มต้น';
$lang['lang']                  = 'ภาษา';
$lang['savedir']               = 'ไดเรคทอรีที่บันทึกข้อมูล';
$lang['basedir']               = 'ไดเรคทอรีพื้นฐาน';
$lang['baseurl']               = 'URL พื้นฐาน';
$lang['recent']                = 'การเปลี่ยนแปลงล่าสุด';
$lang['recent_days']           = 'จำนวนวันที่เก็บรายการที่ถูกแก้ไขล่าสุด';
$lang['signature']             = 'ลายเซนต์';
$lang['hidepages']             = 'ซ่อนหน้าที่เข้ากันได้ (regular expressions)';
$lang['autopasswd']            = 'สร้างรหัสผ่านให้อัตโนมัติ';
$lang['passcrypt']             = 'กระบวนการเข้ารหัส สำหรับเก็บบันทึกรหัสผ่าน';
$lang['defaultgroup']          = 'กลุ่มมาตรฐาน';
$lang['profileconfirm']        = 'ใส่รหัสผ่านเพื่อยืนยันการเปลี่ยนแปลงข้อมูล';
$lang['rememberme']            = 'อนุญาตให้จดจำการ login แบบถาวร';
$lang['disableactions_check']  = 'ตรวจสอบ';
$lang['auth_security_timeout'] = 'ระยะเวลาที่จะตัดการเชื่อมต่อแบบการใช้งานด้วยสิทธิ์ผู้ใช้ (วินาที)';
$lang['usewordblock']          = 'คำที่จะถือว่าเป็นสแปม';
$lang['relnofollow']           = 'ใช้ rel="nofollow" สำหรับลิงก์ภายนอก';
$lang['locktime']              = 'ระยะเวลานานสุด ที่จะล็อคไม่ให้แก้ไขไฟล์ (วินาที)';
$lang['cachetime']             = 'ระยะเวลาสำหรับการเก็บแคช (วินาที)';
$lang['target____wiki']        = 'เปิดแสดงลิงก์ภายใน ในหน้าเว็บแบบใด';
$lang['target____interwiki']   = 'เปิดแสดงลิงก์ interwiki ในหน้าเว็บแบบใด';
$lang['target____extern']      = 'เปิดแสดงลิงก์ภายนอก ในหน้าเว็บแบบใด';
$lang['target____media']       = 'เปิดแสดงลิงก์ของมีเดีย ในหน้าเว็บแบบใด';
$lang['target____windows']     = 'เปิดแสดงลิงก์ของวินโดวส์ ในหน้าเว็บแบบใด';
$lang['gdlib']                 = 'เลขรุ่นของ GD Library';
$lang['fetchsize']             = 'ขนาดไฟล์ใหญ่สุด (bytes) fetch.php ที่จะดาวน์โหลดจากภายนอก';
$lang['notify']                = 'ส่งการแจ้งเตือนไปยังที่อยู่อีเมลนี้';
$lang['sitemap']               = 'สร้าง กูเกิ้ล ไซต์แมพ (จำนวนวัน)';
$lang['rss_type']              = 'ชนิดของ XML feed';
$lang['rss_linkto']            = 'ลิงก์เชื่อมโยงไปยัง XML feed';
$lang['rss_content']           = 'ต้องการให้มีอะไรแสดงอยู่ใน XML feed บ้าง?';
$lang['rss_update']            = 'ความถี่ในการอัพเดท XML feed (เป็นวินาที)';
$lang['rss_show_summary']      = 'ไตเติ้ลของบทสรุปย่อของ XML feed';
$lang['userewrite']            = 'แสดงที่อยู่เว็บ (URL) แบบอ่านเข้าใจง่าย';
$lang['gzip_output']           = 'ใช้ gzip Content-Encoding สำหรับ xhtml';
$lang['compress']              = 'บีบย่อ CSS และ javascript (เพื่อให้แสดงหน้าเว็บเร็วขึ้น)';
$lang['send404']               = 'ให้แสดง "HTTP 404/Page Not Found" เมื่อไม่พบข้อมูลหน้านั้น';
$lang['renderer__core']        = '%s (แกนหลักของ dokuwiki)';
$lang['renderer__plugin']      = '%s (โปรแกรมเสริม - plugin)';
$lang['proxy____host']         = 'ชื่อ server ของ proxy';
$lang['proxy____port']         = 'port ของ proxy';
$lang['proxy____user']         = 'user name ของ proxy';
$lang['proxy____pass']         = 'รหัสผ่านของ proxy';
$lang['proxy____ssl']          = 'ใช้ ssl ในการเชื่อมต่อกับ proxy';
$lang['license_o_']            = 'ไม่ถูกเลือก';
$lang['typography_o_0']        = 'ไม่มี';
$lang['typography_o_1']        = 'ไม่รวมเครื่องหมายอัญประกาศเดี่ยว';
$lang['typography_o_2']        = 'รวมเครื่องหมายอัญประกาศเดี่ยว (อาจใช้ไม่ได้ในบางครั้ง)';
$lang['userewrite_o_0']        = 'ไม่มี';
$lang['userewrite_o_1']        = '.htaccess';
$lang['deaccent_o_0']          = 'ปิด';
$lang['gdlib_o_1']             = 'Version 1.x';
$lang['gdlib_o_2']             = 'ตรวจสอบอัตโนมัติ';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'บทคัดย่อ';
$lang['rss_content_o_html']    = 'หน้าเนื้อหาแบบแสดง HTML เต็มรูปแบบ';
$lang['rss_linkto_o_diff']     = 'มุมมองที่แตกต่าง';
$lang['rss_linkto_o_rev']      = 'รายการของการปรับแก้ไข';
$lang['rss_linkto_o_current']  = 'หน้าปัจจุบัน';
$lang['compression_o_0']       = 'ไม่มีการบีบอัด';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'ไม่ใช้';
$lang['xsendfile_o_2']         = 'หัวเอกสารแบบ Standard X-Sendfile';
$lang['xsendfile_o_3']         = 'หัวเอกสารแบบ Proprietary Nginx X-Accel-Redirect';
$lang['showuseras_o_loginname'] = 'ชื่อผู้ใช้';
$lang['showuseras_o_username'] = 'ชื่อ-นามสกุล';
$lang['showuseras_o_email_link'] = 'อีเมลของผู้ใช้ ที่จะปรากฏ ณ mailto: link';
$lang['useheading_o_0']        = 'ไม่เลย';
$lang['useheading_o_navigation'] = 'เฉพาะตัวนำทาง';
$lang['useheading_o_content']  = 'เฉพาะเนื้อหาวิกิ';
$lang['useheading_o_1']        = 'เสมอ';
